package net.wanji.opt.controller.signalcontrol;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import net.wanji.common.annotation.aspect.AspectLog;
import net.wanji.common.enums.BaseEnum;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.databus.bo.CrossIdBO;
import net.wanji.databus.dto.CrossIdDateTimeDTO;
import net.wanji.databus.vo.ControlCommandVO;
import net.wanji.databus.vo.LightsStatusVO2;
import net.wanji.databus.vo.SchemeOptSendVO;
import net.wanji.opt.service.signalcontrol.FeignProxyService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import javax.validation.constraints.NotBlank;
import javax.ws.rs.core.MediaType;

/**
 * @author duanruiming
 * @date 2023/03/01 20:44
 */
@Api(value = "SignalCommandOptController", description = "信号机控制", tags = "信号机控制")
@RequestMapping("/signalControl")
@RestController
public class SignalCommandOptController {

    @Autowired
    private FeignProxyService feignProxyService;

    @AspectLog(description = "诊断优化手动优化方案下发", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "手动优化方案下发", notes = "优化方案下发", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/schemeOptSend",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({@ApiResponse(code = 200, message = "OK", response = JsonViewObject.class)})
    public JsonViewObject schemeOptSend(@RequestBody @Validated SchemeOptSendVO schemeOptSendVO) throws Exception {
        JsonViewObject jsonViewObject = feignProxyService.schemeOptSend(schemeOptSendVO);
        return jsonViewObject;
    }

    @AspectLog(description = "诊断优化手动优化方案恢复", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "手动优化方案恢复", notes = "优化方案恢复", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @GetMapping(value = "/schemeOptRestore")
    @ApiResponses({@ApiResponse(code = 200, message = "OK", response = JsonViewObject.class)})
    public JsonViewObject schemeOptRestore(@RequestParam(required = true) String crossId) throws Exception {
        JsonViewObject jsonViewObject = feignProxyService.schemeOptRestore(crossId);
        return jsonViewObject;
    }


    @AspectLog(description = "全红控制", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "全红控制", notes = "全红控制", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/allRedControl",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({@ApiResponse(code = 200, message = "OK", response = JsonViewObject.class)})
    public JsonViewObject allRedControl(@RequestBody ControlCommandVO vo) throws Exception {
        //JsonViewObject jsonViewObject = feignProxyService.allRedControl(vo);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance().success();
        return jsonViewObject;
    }

    @AspectLog(description = "黄闪控制", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "黄闪控制", notes = "黄闪控制", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/yellowLightControl",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({@ApiResponse(code = 200, message = "OK", response = JsonViewObject.class)})
    public JsonViewObject yellowLightControl(@RequestBody ControlCommandVO vo) throws Exception {
        //JsonViewObject jsonViewObject = feignProxyService.yellowLightControl(vo);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance().success();
        return jsonViewObject;
    }

    @AspectLog(description = "步进控制", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "步进控制", notes = "步进控制", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/stepControl",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({@ApiResponse(code = 200, message = "OK", response = JsonViewObject.class)})
    public JsonViewObject stepControl(String crossId, Integer command, Integer stepNum) throws Exception {
        //JsonViewObject jsonViewObject = feignProxyService.stepControl(crossId, command, stepNum);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance().success();
        return jsonViewObject;
    }

    @AspectLog(description = "相位锁定", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "相位锁定", notes = "相位锁定", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/lockControl",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({@ApiResponse(code = 200, message = "OK", response = JsonViewObject.class)})
    public JsonViewObject lockControl(@RequestBody ControlCommandVO vo) throws Exception {
        //JsonViewObject jsonViewObject = feignProxyService.lockControl(vo);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance().success();
        return jsonViewObject;
    }

    @AspectLog(description = "恢复时间表", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "恢复时间表", notes = "恢复时间表", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/recoverSchedule",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({@ApiResponse(code = 200, message = "OK", response = JsonViewObject.class)})
    public JsonViewObject recoverSchedule(@RequestBody CrossIdBO crossIdBO) throws Exception {
        //JsonViewObject jsonViewObject = feignProxyService.recoverSchedule(crossIdBO);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance().success();
        return jsonViewObject;
    }

    @AspectLog(description = "查询某一时间灯态历史数据", operationType = BaseEnum.OperationTypeEnum.QUERY)
    @PostMapping(value = "/lightStatusOneHist", produces = MediaType.APPLICATION_JSON)
    @ApiOperation(value = "查询某一时间灯态历史数据", notes = "查询某一时间灯态历史数据", response = LightsStatusVO2.class,
            produces = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = LightsStatusVO2.class)
    })
    public JsonViewObject lightStatusOneHist(@RequestBody @Valid CrossIdDateTimeDTO crossIdDateTimeDTO) throws Exception {
        return feignProxyService.lightStatusOneHist(crossIdDateTimeDTO);
    }
}
